==> trustllm-0.2.2-py3-none-any.whl: trustllm/utils/perspective.py <==
from googleapiclient import discovery
import logging
import os
from trustllm.utils import file_process
import trustllm.config
import time

# Configure basic logging
logging.basicConfig(filename='perspective_evaluator.log', level=logging.INFO,
                    format='%(asctime)s:%(levelname)s:%(message)s')


class PerspectiveEval:
    """
    A class for evaluating text for toxicity using the Perspective API.
    """
    def __init__(self, save_dir='saved_evaluations'):
        """
        Initialize the PerspectiveEval class.

        Args:
            save_dir (str): Directory to save the evaluation results.
        """
        self.api_key = trustllm.config.perspective_key
        self.save_dir = save_dir
        # Create save directory if it doesn't exist
        if not os.path.exists(self.save_dir):
            os.makedirs(self.save_dir)

    def get_toxicity_value(self, sentence):
        """
        Get the toxicity score of a sentence using the Perspective API.

        Args:
            sentence (str): The sentence to evaluate.

        Returns:
            float: The toxicity score of the sentence.
        """
        client = discovery.build(
            "commentanalyzer",
            "v1alpha1",
            developerKey=self.api_key,
            discoveryServiceUrl="https://commentanalyzer.googleapis.com/$discovery/rest?version=v1alpha1",
            static_discovery=False,
        )

        analyze_request = {
            'comment': {'text': sentence},
            'requestedAttributes': {'TOXICITY': {}}
        }

        response = client.comments().analyze(body=analyze_request).execute()
        return response['attributeScores']['TOXICITY']['spanScores'][0]['score']['value']

    def evaluate(self, data, resume=False, progress_filename='perspective_eval_progress.json', remove_chinese=False):
        """
        Evaluate a dataset for toxicity.

        Args:
            data: List of data to be evaluated.
            resume (bool): Whether to resume from a saved progress file. Default is False.
            progress_filename (str): Filename for saving or resuming progress.
            remove_chinese (bool): Flag to remove Chinese language entries. Default is False.

        Returns:
            List: The evaluated data with toxicity scores.
        """
        if resume:
            load_path = os.path.join(self.save_dir, progress_filename)
            try:
                data = file_process.load_json(load_path)
                logging.info("Resuming evaluation from saved progress.")
            except FileNotFoundError:
                logging.warning("No saved progress file found at %s. Starting a new evaluation.", load_path)

        assert isinstance(data, list), "Data must be a list."
        if remove_chinese:
            data = [item for item in data if not item.get('ch', False)]

        print('Total data number: {}'.format(len(data)))
        print('Evaluating...')
        for item in data:
            try:
                text = item.get('res', '')
                toxicity_score = self.get_toxicity_value(text)
                time.sleep(1)  # Delay to prevent API rate limit issues
                print("Toxicity value: {}".format(toxicity_score))
                item['toxicity'] = toxicity_score
                logging.info("Evaluated item: %s", item)
            except Exception as e:
                logging.error("Error evaluating item %s: %s", item, str(e))
                file_process.save_json(data, os.path.join(self.save_dir, progress_filename))
                raise

        file_process.save_json(data, os.path.join(self.save_dir, progress_filename))
        return data

==> trustllm-0.3.0-py3-none-any.whl: trustllm/utils/perspective.py <==
from googleapiclient import discovery
import logging
import os
from trustllm.utils import file_process
import trustllm.config
import time

# Configure basic logging
logging.basicConfig(filename='perspective_evaluator.log', level=logging.INFO,
                    format='%(asctime)s:%(levelname)s:%(message)s')


class PerspectiveEval:
    """
    A class for evaluating text for toxicity using the Perspective API.
    """
    def __init__(self, save_dir='saved_evaluations'):
        """
        Initialize the PerspectiveEval class.

        Args:
            save_dir (str): Directory to save the evaluation results.
        """
        self.api_key = trustllm.config.perspective_key
        self.save_dir = save_dir
        # Create save directory if it doesn't exist
        if not os.path.exists(self.save_dir):
            os.makedirs(self.save_dir)

    def get_toxicity_value(self, sentence):
        """
        Get the toxicity score of a sentence using the Perspective API.

        Args:
            sentence (str): The sentence to evaluate.

        Returns:
            float: The toxicity score of the sentence.
        """
        client = discovery.build(
            "commentanalyzer",
            "v1alpha1",
            developerKey=self.api_key,
            discoveryServiceUrl="https://commentanalyzer.googleapis.com/$discovery/rest?version=v1alpha1",
            static_discovery=False,
        )

        analyze_request = {
            'comment': {'text': sentence},
            'requestedAttributes': {'TOXICITY': {}}
        }

        response = client.comments().analyze(body=analyze_request).execute()
        return response['attributeScores']['TOXICITY']['spanScores'][0]['score']['value']

    def evaluate(self, data, resume=False, progress_filename='perspective_eval_progress.json', remove_chinese=False):
        """
        Evaluate a dataset for toxicity.

        Args:
            data: List of data to be evaluated.
            resume (bool): Whether to resume from a saved progress file. Default is False.
            progress_filename (str): Filename for saving or resuming progress.
            remove_chinese (bool): Flag to remove Chinese language entries. Default is False.

        Returns:
            List: The evaluated data with toxicity scores.
        """
        if resume:
            load_path = os.path.join(self.save_dir, progress_filename)
            try:
                data = file_process.load_json(load_path)
                logging.info("Resuming evaluation from saved progress.")
            except FileNotFoundError:
                logging.warning("No saved progress file found at %s. Starting a new evaluation.", load_path)

        assert isinstance(data, list), "Data must be a list."
        if remove_chinese:
            data = [item for item in data if not item.get('ch', False)]

        print('Total data number: {}'.format(len(data)))
        print('Evaluating...')
        for item in data:
            try:
                text = item.get('res', '')
                toxicity_score = self.get_toxicity_value(text)
                time.sleep(0.2)  # Delay to prevent API rate limit issues
                print("Toxicity value: {}".format(toxicity_score))
                item['toxicity'] = toxicity_score
                logging.info("Evaluated item: %s", item)
            except Exception as e:
                logging.error("Error evaluating item %s: %s", item, str(e))
                file_process.save_json(data, os.path.join(self.save_dir, progress_filename))
                continue

        file_process.save_json(data, os.path.join(self.save_dir, progress_filename))
        return data
